from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from wds_client.api.cloning_api import CloningApi
from wds_client.api.general_wds_information_api import GeneralWDSInformationApi
from wds_client.api.import_api import ImportApi
from wds_client.api.instances_api import InstancesApi
from wds_client.api.job_api import JobApi
from wds_client.api.records_api import RecordsApi
from wds_client.api.schema_api import SchemaApi
from wds_client.api.snapshots_api import SnapshotsApi



# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs. As of v0.2, all APIs are subject to change without notice.   # noqa: E501

    The version of the OpenAPI document: v0.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from wds_client.configuration import Configuration


class SearchRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'offset': 'int',
        'limit': 'int',
        'sort': 'SearchSortDirection',
        'sort_attribute': 'str'
    }

    attribute_map = {
        'offset': 'offset',
        'limit': 'limit',
        'sort': 'sort',
        'sort_attribute': 'sortAttribute'
    }

    def __init__(self, offset=0, limit=10, sort=None, sort_attribute=None, local_vars_configuration=None):  # noqa: E501
        """SearchRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._offset = None
        self._limit = None
        self._sort = None
        self._sort_attribute = None
        self.discriminator = None

        if offset is not None:
            self.offset = offset
        if limit is not None:
            self.limit = limit
        if sort is not None:
            self.sort = sort
        if sort_attribute is not None:
            self.sort_attribute = sort_attribute

    @property
    def offset(self):
        """Gets the offset of this SearchRequest.  # noqa: E501

        Pagination offset  # noqa: E501

        :return: The offset of this SearchRequest.  # noqa: E501
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this SearchRequest.

        Pagination offset  # noqa: E501

        :param offset: The offset of this SearchRequest.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                offset is not None and offset < 0):  # noqa: E501
            raise ValueError("Invalid value for `offset`, must be a value greater than or equal to `0`")  # noqa: E501

        self._offset = offset

    @property
    def limit(self):
        """Gets the limit of this SearchRequest.  # noqa: E501

        Pagination limit  # noqa: E501

        :return: The limit of this SearchRequest.  # noqa: E501
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this SearchRequest.

        Pagination limit  # noqa: E501

        :param limit: The limit of this SearchRequest.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                limit is not None and limit > 1000):  # noqa: E501
            raise ValueError("Invalid value for `limit`, must be a value less than or equal to `1000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                limit is not None and limit < 0):  # noqa: E501
            raise ValueError("Invalid value for `limit`, must be a value greater than or equal to `0`")  # noqa: E501

        self._limit = limit

    @property
    def sort(self):
        """Gets the sort of this SearchRequest.  # noqa: E501


        :return: The sort of this SearchRequest.  # noqa: E501
        :rtype: SearchSortDirection
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this SearchRequest.


        :param sort: The sort of this SearchRequest.  # noqa: E501
        :type: SearchSortDirection
        """

        self._sort = sort

    @property
    def sort_attribute(self):
        """Gets the sort_attribute of this SearchRequest.  # noqa: E501


        :return: The sort_attribute of this SearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._sort_attribute

    @sort_attribute.setter
    def sort_attribute(self, sort_attribute):
        """Sets the sort_attribute of this SearchRequest.


        :param sort_attribute: The sort_attribute of this SearchRequest.  # noqa: E501
        :type: str
        """

        self._sort_attribute = sort_attribute

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SearchRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs. As of v0.2, all APIs are subject to change without notice.   # noqa: E501

    The version of the OpenAPI document: v0.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from wds_client.configuration import Configuration


class ErrorResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'status': 'int',
        'error': 'str',
        'message': 'str',
        'path': 'str',
        'timestamp': 'str'
    }

    attribute_map = {
        'status': 'status',
        'error': 'error',
        'message': 'message',
        'path': 'path',
        'timestamp': 'timestamp'
    }

    def __init__(self, status=None, error=None, message=None, path=None, timestamp=None, local_vars_configuration=None):  # noqa: E501
        """ErrorResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._status = None
        self._error = None
        self._message = None
        self._path = None
        self._timestamp = None
        self.discriminator = None

        self.status = status
        self.error = error
        self.message = message
        self.path = path
        self.timestamp = timestamp

    @property
    def status(self):
        """Gets the status of this ErrorResponse.  # noqa: E501

        HTTP status code  # noqa: E501

        :return: The status of this ErrorResponse.  # noqa: E501
        :rtype: int
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ErrorResponse.

        HTTP status code  # noqa: E501

        :param status: The status of this ErrorResponse.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def error(self):
        """Gets the error of this ErrorResponse.  # noqa: E501

        error  # noqa: E501

        :return: The error of this ErrorResponse.  # noqa: E501
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this ErrorResponse.

        error  # noqa: E501

        :param error: The error of this ErrorResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and error is None:  # noqa: E501
            raise ValueError("Invalid value for `error`, must not be `None`")  # noqa: E501

        self._error = error

    @property
    def message(self):
        """Gets the message of this ErrorResponse.  # noqa: E501

        error message  # noqa: E501

        :return: The message of this ErrorResponse.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ErrorResponse.

        error message  # noqa: E501

        :param message: The message of this ErrorResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and message is None:  # noqa: E501
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    @property
    def path(self):
        """Gets the path of this ErrorResponse.  # noqa: E501

        requested record path  # noqa: E501

        :return: The path of this ErrorResponse.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this ErrorResponse.

        requested record path  # noqa: E501

        :param path: The path of this ErrorResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and path is None:  # noqa: E501
            raise ValueError("Invalid value for `path`, must not be `None`")  # noqa: E501

        self._path = path

    @property
    def timestamp(self):
        """Gets the timestamp of this ErrorResponse.  # noqa: E501

        time of error  # noqa: E501

        :return: The timestamp of this ErrorResponse.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this ErrorResponse.

        time of error  # noqa: E501

        :param timestamp: The timestamp of this ErrorResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and timestamp is None:  # noqa: E501
            raise ValueError("Invalid value for `timestamp`, must not be `None`")  # noqa: E501

        self._timestamp = timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ErrorResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ErrorResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs. As of v0.2, all APIs are subject to change without notice.   # noqa: E501

    The version of the OpenAPI document: v0.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import wds_client
from wds_client.models.version_response import VersionResponse  # noqa: E501
from wds_client.rest import ApiException

class TestVersionResponse(unittest.TestCase):
    """VersionResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test VersionResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = wds_client.models.version_response.VersionResponse()  # noqa: E501
        if include_optional :
            return VersionResponse(
                app = wds_client.models.app.app(
                    chart_version = '0', 
                    image = '0', ), 
                git = wds_client.models.git.git(
                    branch = '0', 
                    commit = wds_client.models.commit.commit(
                        id = '0', 
                        time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                build = wds_client.models.build.build(
                    artifact = '0', 
                    name = '0', 
                    time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    version = '0', 
                    group = '0', )
            )
        else :
            return VersionResponse(
        )

    def testVersionResponse(self):
        """Test VersionResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs. As of v0.2, all APIs are subject to change without notice.   # noqa: E501

    The version of the OpenAPI document: v0.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from wds_client.configuration import Configuration


class Components(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'db': 'DbComponent',
        'disk_space': 'DiskSpaceComponent',
        'ping': 'Component',
        'main_db': 'DbValidationcomponent'
    }

    attribute_map = {
        'db': 'db',
        'disk_space': 'diskSpace',
        'ping': 'ping',
        'main_db': 'mainDb'
    }

    def __init__(self, db=None, disk_space=None, ping=None, main_db=None, local_vars_configuration=None):  # noqa: E501
        """Components - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._db = None
        self._disk_space = None
        self._ping = None
        self._main_db = None
        self.discriminator = None

        if db is not None:
            self.db = db
        if disk_space is not None:
            self.disk_space = disk_space
        if ping is not None:
            self.ping = ping
        if main_db is not None:
            self.main_db = main_db

    @property
    def db(self):
        """Gets the db of this Components.  # noqa: E501


        :return: The db of this Components.  # noqa: E501
        :rtype: DbComponent
        """
        return self._db

    @db.setter
    def db(self, db):
        """Sets the db of this Components.


        :param db: The db of this Components.  # noqa: E501
        :type: DbComponent
        """

        self._db = db

    @property
    def disk_space(self):
        """Gets the disk_space of this Components.  # noqa: E501


        :return: The disk_space of this Components.  # noqa: E501
        :rtype: DiskSpaceComponent
        """
        return self._disk_space

    @disk_space.setter
    def disk_space(self, disk_space):
        """Sets the disk_space of this Components.


        :param disk_space: The disk_space of this Components.  # noqa: E501
        :type: DiskSpaceComponent
        """

        self._disk_space = disk_space

    @property
    def ping(self):
        """Gets the ping of this Components.  # noqa: E501


        :return: The ping of this Components.  # noqa: E501
        :rtype: Component
        """
        return self._ping

    @ping.setter
    def ping(self, ping):
        """Sets the ping of this Components.


        :param ping: The ping of this Components.  # noqa: E501
        :type: Component
        """

        self._ping = ping

    @property
    def main_db(self):
        """Gets the main_db of this Components.  # noqa: E501


        :return: The main_db of this Components.  # noqa: E501
        :rtype: DbValidationcomponent
        """
        return self._main_db

    @main_db.setter
    def main_db(self, main_db):
        """Sets the main_db of this Components.


        :param main_db: The main_db of this Components.  # noqa: E501
        :type: DbValidationcomponent
        """

        self._main_db = main_db

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Components):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Components):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs. As of v0.2, all APIs are subject to change without notice.   # noqa: E501

    The version of the OpenAPI document: v0.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import wds_client
from wds_client.models.status_response import StatusResponse  # noqa: E501
from wds_client.rest import ApiException

class TestStatusResponse(unittest.TestCase):
    """StatusResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test StatusResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = wds_client.models.status_response.StatusResponse()  # noqa: E501
        if include_optional :
            return StatusResponse(
                status = '0', 
                components = wds_client.models.components.components(
                    db = wds_client.models.db_component.dbComponent(
                        status = '0', ), 
                    disk_space = wds_client.models.disk_space_component.diskSpaceComponent(
                        status = '0', 
                        details = wds_client.models.disk_space_component_details.diskSpaceComponentDetails(
                            total = '0', 
                            free = 1.337, 
                            threshold = 1.337, 
                            exists = True, ), ), 
                    ping = wds_client.models.component.component(
                        status = '0', ), 
                    main_db = wds_client.models.db_validationcomponent.dbValidationcomponent(
                        status = '0', ), )
            )
        else :
            return StatusResponse(
        )

    def testStatusResponse(self):
        """Test StatusResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs. As of v0.2, all APIs are subject to change without notice.   # noqa: E501

    The version of the OpenAPI document: v0.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import wds_client
from wds_client.models.request_body_search import RequestBodySearch  # noqa: E501
from wds_client.rest import ApiException

class TestRequestBodySearch(unittest.TestCase):
    """RequestBodySearch unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test RequestBodySearch
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = wds_client.models.request_body_search.RequestBodySearch()  # noqa: E501
        if include_optional :
            return RequestBodySearch(
                terms = '0', 
                operator = 'and'
            )
        else :
            return RequestBodySearch(
                terms = '0',
        )

    def testRequestBodySearch(self):
        """Test RequestBodySearch"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Workspace Data Service

    This page lists current APIs. As of v0.2, all APIs are subject to change without notice.   # noqa: E501

    The version of the OpenAPI document: v0.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "0.2.104"

# import apis into sdk package
from wds_client.api.cloning_api import CloningApi
from wds_client.api.general_wds_information_api import GeneralWDSInformationApi
from wds_client.api.import_api import ImportApi
from wds_client.api.instances_api import InstancesApi
from wds_client.api.job_api import JobApi
from wds_client.api.records_api import RecordsApi
from wds_client.api.schema_api import SchemaApi
from wds_client.api.snapshots_api import SnapshotsApi

# import ApiClient
from wds_client.api_client import ApiClient
from wds_client.configuration import Configuration
from wds_client.exceptions import OpenApiException
from wds_client.exceptions import ApiTypeError
from wds_client.exceptions import ApiValueError
from wds_client.exceptions import ApiKeyError
from wds_client.exceptions import ApiException
# import models into sdk package
from wds_client.models.app import App
from wds_client.models.attribute_schema import AttributeSchema
from wds_client.models.backup_job import BackupJob
from wds_client.models.backup_job_all_of import BackupJobAllOf
from wds_client.models.backup_response import BackupResponse
from wds_client.models.backup_restore_request import BackupRestoreRequest
from wds_client.models.batch_operation import BatchOperation
from wds_client.models.batch_record_request import BatchRecordRequest
from wds_client.models.batch_response import BatchResponse
from wds_client.models.build import Build
from wds_client.models.clone_job import CloneJob
from wds_client.models.clone_job_all_of import CloneJobAllOf
from wds_client.models.clone_response import CloneResponse
from wds_client.models.commit import Commit
from wds_client.models.component import Component
from wds_client.models.components import Components
from wds_client.models.db_component import DbComponent
from wds_client.models.db_validationcomponent import DbValidationcomponent
from wds_client.models.db_validationcomponent_details import DbValidationcomponentDetails
from wds_client.models.disk_space_component import DiskSpaceComponent
from wds_client.models.disk_space_component_details import DiskSpaceComponentDetails
from wds_client.models.error_response import ErrorResponse
from wds_client.models.generic_job import GenericJob
from wds_client.models.generic_job_all_of import GenericJobAllOf
from wds_client.models.git import Git
from wds_client.models.import_request import ImportRequest
from wds_client.models.inline_object import InlineObject
from wds_client.models.job import Job
from wds_client.models.job_v1 import JobV1
from wds_client.models.record_query_response import RecordQueryResponse
from wds_client.models.record_request import RecordRequest
from wds_client.models.record_response import RecordResponse
from wds_client.models.record_type_schema import RecordTypeSchema
from wds_client.models.request_body_search import RequestBodySearch
from wds_client.models.search_operator import SearchOperator
from wds_client.models.search_request import SearchRequest
from wds_client.models.search_sort_direction import SearchSortDirection
from wds_client.models.stack_trace_element import StackTraceElement
from wds_client.models.status_response import StatusResponse
from wds_client.models.tsv_upload_response import TsvUploadResponse
from wds_client.models.version_response import VersionResponse

